@@ -5,13 +5,26 @@
 
 #include <dirent.h>
 
+#undef MY_DIR
+#undef MY_DIRENT
+
+#undef MY_DIRENT
+
+#if defined(_WIN32)
+  #include "Sys-Windows.h"
+  
+  #define MY_DIRENT struct _wdirent
+#else
+  #define MY_DIRENT struct dirent
+#endif
+
 static const char* FILE_NAME = "Sys/IO/Dirent.c";
 
 int32_t SPVM__Sys__IO__Dirent__d_ino(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dirent = stack[0].oval;
   
-  struct dirent* st_dirent = env->get_pointer(env, stack, obj_dirent);
+  MY_DIRENT* st_dirent = env->get_pointer(env, stack, obj_dirent);
   
   stack[0].ival = st_dirent->d_ino;
   
@@ -20,11 +33,22 @@ int32_t SPVM__Sys__IO__Dirent__d_ino(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__IO__Dirent__d_name(SPVM_ENV* env, SPVM_VALUE* stack) {
   
+  int32_t error_id = 0;
+  
   void* obj_dirent = stack[0].oval;
   
-  struct dirent* st_dirent = env->get_pointer(env, stack, obj_dirent);
+  MY_DIRENT* st_dirent = env->get_pointer(env, stack, obj_dirent);
   
+#if defined(_WIN32)
+  const wchar_t* d_name_w = st_dirent->d_name;
+  const char* d_name = (char*)win_wchar_to_utf8(env, stack, (wchar_t*)d_name_w, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) {
+    return error_id;
+  }
+#else
   const char* d_name = st_dirent->d_name;
+#endif
+  
   int32_t d_name_length = strlen(d_name);
   
   void* obj_d_name = env->new_string(env, stack, d_name, d_name_length);
@@ -42,7 +66,7 @@ int32_t SPVM__Sys__IO__Dirent__d_reclen(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dirent = stack[0].oval;
   
-  struct dirent* st_dirent = env->get_pointer(env, stack, obj_dirent);
+  MY_DIRENT* st_dirent = env->get_pointer(env, stack, obj_dirent);
   
   stack[0].ival = st_dirent->d_reclen;
   
@@ -58,7 +82,7 @@ int32_t SPVM__Sys__IO__Dirent__d_type(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* obj_dirent = stack[0].oval;
   
-  struct dirent* st_dirent = env->get_pointer(env, stack, obj_dirent);
+  MY_DIRENT* st_dirent = env->get_pointer(env, stack, obj_dirent);
   
   stack[0].ival = st_dirent->d_type;
   
@@ -79,7 +103,7 @@ int32_t SPVM__Sys__IO__Dirent__d_off(SPVM_ENV* env, SPVM_VALUE* stack) {
 #else
   void* obj_dirent = stack[0].oval;
   
-  struct dirent* st_dirent = env->get_pointer(env, stack, obj_dirent);
+  MY_DIRENT* st_dirent = env->get_pointer(env, stack, obj_dirent);
   
   stack[0].lval = st_dirent->d_off;
   
